﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DataGridForegroundBinding
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
    }

    public class SampleDataItem : INotifyPropertyChanged
    {
        public string name { get; set; }
        public string department { get; set; }
        public double salary { get; set; }
        public string email { get; set; }

        private string _showColor;
        public string ShowColor
        {
            get { return _showColor; }
            set
            {
                if (_showColor != value)
                {
                    _showColor = value;
                    OnPropertyChanged("ShowColor");
                }
            }
        }

        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }

    public class SampleData : ObservableCollection<SampleDataItem>
    {
        public SampleData()
        {
            Add(new SampleDataItem { name = "Joe", department = "Sales", salary = 70000.0, email = "joe@email.com" });
            Add(new SampleDataItem { name = "Mary", department = "Engineering", salary = 71000.0, email = "mary@email.com" });
            Add(new SampleDataItem { name = "Jim", department = "Sales", salary = 72000.0, email = "jim@email.com" });
        }
    }

    public class ColorToForeBrushConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value is Color)
            {
                return new SolidColorBrush((Color)value);
            }
            else if (value is string)
            {
                string ColorString = (string)value;
                if (ColorString == "") //no specified Foreground
                {
                    return Binding.DoNothing;
                }
                else
                {
                    return new SolidColorBrush((Color)(ColorConverter.ConvertFromString(ColorString)));
                }
            }
            return Binding.DoNothing;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class IsValidColor : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value == null || (value is string && (string)value == ""))
                return false;

            return true;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
